@@ -131,7 +131,7 @@ QSys = R6::R6Class("QSys",
         id = function() private$port,
         url = function() private$listen,
         sock = function() private$socket,
-        workers = function() private$job_num,
+        workers = function() private$workers_total,
         workers_running = function() private$workers_up,
         data_token = function() private$token,
         reusable = function() private$reuse
@@ -144,10 +144,9 @@ QSys = R6::R6Class("QSys",
         master = NULL,
         listen = NULL,
         timer = NULL,
-        job_group = NULL,
-        job_num = 0,
         common_data = NULL,
         token = "not set",
+        workers_total = 0,
         workers_up = 0,
         worker_stats = list(),
         reuse = NULL,
