@@ -2,34 +2,37 @@ context("worker")
 
 context = rzmq::init.context()
 socket = rzmq::init.socket(context, "ZMQ_REP")
-rzmq::bind.socket(socket, "tcp://*:55443")
+port = try(bind_avail(socket, 55000:57000, n_tries=10))
+master = paste("tcp://localhost", port, sep=":")
 Sys.sleep(0.5)
 
-start_worker = function(master="tcp://localhost:55443") {
+start_worker = function() {
     skip_on_os("windows")
 
+    if (class(port) == "try-error")
+        skip("Failed to bind port")
+
     p = parallel::mcparallel(worker(master))
-    msg = recv(socket)
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_UP")
     p
 }
 
 send_common = function(fun=function(x) x) {
     send(socket, list(id="DO_SETUP", fun=fun, const=list(),
-                export=list(), common_seed=1, token="token"))
-    msg = recv(socket)
+         export=list(), common_seed=1, token="token"))
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_READY")
 }
 
 shutdown_worker = function(p) {
     send(socket, list(id="WORKER_STOP"))
-    msg = recv(socket)
+    msg = recv(p, socket)
     send(socket, list()) # already shut down
     testthat::expect_equal(msg$id, "WORKER_DONE")
     testthat::expect_is(msg$time, "proc_time")
     testthat::expect_is(msg$calls, "numeric")
-    parallel::mccollect(p)
-    Sys.sleep(0.5)
+    clean_collect(p)
 }
 
 test_that("sending common data", {
@@ -42,7 +45,7 @@ test_that("invalid common data", {
     p = start_worker()
 
     send(socket, list(id="DO_SETUP", invalid=TRUE))
-    msg = recv(socket)
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_ERROR")
 
     shutdown_worker(p)
@@ -51,8 +54,8 @@ test_that("invalid common data", {
 test_that("common data redirect", {
     p = start_worker()
 
-    send(socket, list(id="DO_SETUP", redirect="tcp://localhost:55443"))
-    msg = recv(socket)
+    send(socket, list(id="DO_SETUP", redirect=master))
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_UP")
 
     send_common()
@@ -65,7 +68,7 @@ test_that("do work", {
 
     # should probably also test for error when DO_CHUNK but no chunk provided
     send(socket, list(id="DO_CHUNK", chunk=data.frame(x=5), token="token"))
-    msg = recv(socket)
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_READY")
     testthat::expect_equal(msg$result, list(`1`=5))
 
@@ -78,7 +81,7 @@ test_that("token mismatch", {
 
     # should probably also test for error when DO_CHUNK but no chunk provided
     send(socket, list(id="DO_CHUNK", chunk=data.frame(x=5), token="token2"))
-    msg = recv(socket)
+    msg = recv(p, socket)
     testthat::expect_equal(msg$id, "WORKER_ERROR")
 
     shutdown_worker(p)
